# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: regfile.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'regfile.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rregfile.proto\x1a\nopts.proto\x1a\nfown.proto\"\x89\x02\n\x0ereg_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x1f\n\x05\x66lags\x18\x02 \x02(\rB\x10\xd2?\r\x1a\x0brfile.flags\x12\x0b\n\x03pos\x18\x03 \x02(\x04\x12\x19\n\x04\x66own\x18\x05 \x02(\x0b\x32\x0b.fown_entry\x12\x0c\n\x04name\x18\x06 \x02(\t\x12\x12\n\x06mnt_id\x18\x07 \x01(\x11:\x02-1\x12\x0c\n\x04size\x18\x08 \x01(\x04\x12\x0b\n\x03\x65xt\x18\t \x01(\x08\x12\x0c\n\x04mode\x18\n \x01(\r\x12\x10\n\x08\x62uild_id\x18\x0b \x03(\r\x12\x10\n\x08\x63hecksum\x18\x0c \x01(\r\x12\x17\n\x0f\x63hecksum_config\x18\r \x01(\r\x12\x1a\n\x12\x63hecksum_parameter\x18\x0e \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'regfile_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REG_FILE_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_REG_FILE_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\r\032\013rfile.flags'
  _globals['_REG_FILE_ENTRY']._serialized_start=42
  _globals['_REG_FILE_ENTRY']._serialized_end=307
# @@protoc_insertion_point(module_scope)
