# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ext-file.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'ext-file.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x65xt-file.proto\x1a\nfown.proto\"7\n\x0e\x65xt_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x19\n\x04\x66own\x18\x05 \x02(\x0b\x32\x0b.fown_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ext_file_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EXT_FILE_ENTRY']._serialized_start=30
  _globals['_EXT_FILE_ENTRY']._serialized_end=85
# @@protoc_insertion_point(module_scope)
