# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: creds.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'creds.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x63reds.proto\"\xcd\x02\n\x0b\x63reds_entry\x12\x0b\n\x03uid\x18\x01 \x02(\r\x12\x0b\n\x03gid\x18\x02 \x02(\r\x12\x0c\n\x04\x65uid\x18\x03 \x02(\r\x12\x0c\n\x04\x65gid\x18\x04 \x02(\r\x12\x0c\n\x04suid\x18\x05 \x02(\r\x12\x0c\n\x04sgid\x18\x06 \x02(\r\x12\r\n\x05\x66suid\x18\x07 \x02(\r\x12\r\n\x05\x66sgid\x18\x08 \x02(\r\x12\x0f\n\x07\x63\x61p_inh\x18\t \x03(\r\x12\x0f\n\x07\x63\x61p_prm\x18\n \x03(\r\x12\x0f\n\x07\x63\x61p_eff\x18\x0b \x03(\r\x12\x0f\n\x07\x63\x61p_bnd\x18\x0c \x03(\r\x12\x0f\n\x07secbits\x18\r \x02(\r\x12\x0e\n\x06groups\x18\x0e \x03(\r\x12\x13\n\x0blsm_profile\x18\x0f \x01(\t\x12\x16\n\x0elsm_sockcreate\x18\x10 \x01(\t\x12\x15\n\rapparmor_data\x18\x11 \x01(\x0c\x12\x14\n\x0cno_new_privs\x18\x12 \x01(\r\x12\x0f\n\x07\x63\x61p_amb\x18\x13 \x03(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'creds_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CREDS_ENTRY']._serialized_start=16
  _globals['_CREDS_ENTRY']._serialized_end=349
# @@protoc_insertion_point(module_scope)
