# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ghost-file.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'ghost-file.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import time_pb2 as time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10ghost-file.proto\x1a\nopts.proto\x1a\ntime.proto\"\xd7\x01\n\x10ghost_file_entry\x12\x0b\n\x03uid\x18\x01 \x02(\r\x12\x0b\n\x03gid\x18\x02 \x02(\r\x12\x0c\n\x04mode\x18\x03 \x02(\r\x12\x12\n\x03\x64\x65v\x18\x04 \x01(\rB\x05\xd2?\x02 \x01\x12\x0b\n\x03ino\x18\x05 \x01(\x04\x12\x15\n\x04rdev\x18\x06 \x01(\rB\x07\xd2?\x04 \x01(\x01\x12\x16\n\x04\x61tim\x18\x07 \x01(\x0b\x32\x08.timeval\x12\x16\n\x04mtim\x18\x08 \x01(\x0b\x32\x08.timeval\x12\x0e\n\x06\x63hunks\x18\t \x01(\x08\x12\x0c\n\x04size\x18\n \x01(\x04\x12\x15\n\rsymlnk_target\x18\x0b \x01(\t\"-\n\x11ghost_chunk_entry\x12\x0b\n\x03len\x18\x01 \x02(\x04\x12\x0b\n\x03off\x18\x02 \x02(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ghost_file_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GHOST_FILE_ENTRY'].fields_by_name['dev']._loaded_options = None
  _globals['_GHOST_FILE_ENTRY'].fields_by_name['dev']._serialized_options = b'\322?\002 \001'
  _globals['_GHOST_FILE_ENTRY'].fields_by_name['rdev']._loaded_options = None
  _globals['_GHOST_FILE_ENTRY'].fields_by_name['rdev']._serialized_options = b'\322?\004 \001(\001'
  _globals['_GHOST_FILE_ENTRY']._serialized_start=45
  _globals['_GHOST_FILE_ENTRY']._serialized_end=260
  _globals['_GHOST_CHUNK_ENTRY']._serialized_start=262
  _globals['_GHOST_CHUNK_ENTRY']._serialized_end=307
# @@protoc_insertion_point(module_scope)
