# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sa.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'sa.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x08sa.proto\x1a\nopts.proto\"\xa0\x01\n\x08sa_entry\x12\x18\n\tsigaction\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x14\n\x05\x66lags\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x17\n\x08restorer\x18\x03 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x13\n\x04mask\x18\x04 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x18\n\x10\x63ompat_sigaction\x18\x05 \x01(\x08\x12\x1c\n\rmask_extended\x18\x06 \x01(\x04\x42\x05\xd2?\x02\x08\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sa_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['sigaction']._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['sigaction']._serialized_options = b'\322?\002\010\001'
  _globals['_SA_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_SA_ENTRY'].fields_by_name['restorer']._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['restorer']._serialized_options = b'\322?\002\010\001'
  _globals['_SA_ENTRY'].fields_by_name['mask']._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['mask']._serialized_options = b'\322?\002\010\001'
  _globals['_SA_ENTRY'].fields_by_name['mask_extended']._loaded_options = None
  _globals['_SA_ENTRY'].fields_by_name['mask_extended']._serialized_options = b'\322?\002\010\001'
  _globals['_SA_ENTRY']._serialized_start=25
  _globals['_SA_ENTRY']._serialized_end=185
# @@protoc_insertion_point(module_scope)
