/* Autogenerated, do not edit */
#ifndef __CR_VERSION_H__
#define __CR_VERSION_H__
#define CRIU_VERSION "4.2"
#define CRIU_VERSION_MAJOR  4
#define CRIU_VERSION_MINOR  2
#define CRIU_GITID "v4.2"
#endif /* __CR_VERSION_H__ */
