# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: timens.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'timens.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ctimens.proto\"+\n\x08timespec\x12\x0e\n\x06tv_sec\x18\x01 \x02(\x04\x12\x0f\n\x07tv_nsec\x18\x02 \x02(\x04\"I\n\x0ctimens_entry\x12\x1c\n\tmonotonic\x18\x01 \x02(\x0b\x32\t.timespec\x12\x1b\n\x08\x62oottime\x18\x02 \x02(\x0b\x32\t.timespec')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'timens_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TIMESPEC']._serialized_start=16
  _globals['_TIMESPEC']._serialized_end=59
  _globals['_TIMENS_ENTRY']._serialized_start=61
  _globals['_TIMENS_ENTRY']._serialized_end=134
# @@protoc_insertion_point(module_scope)
