# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: autofs.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'autofs.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x61utofs.proto\"\x96\x01\n\x0c\x61utofs_entry\x12\n\n\x02\x66\x64\x18\x01 \x02(\x05\x12\x0c\n\x04pgrp\x18\x02 \x02(\x05\x12\x0f\n\x07timeout\x18\x03 \x02(\x05\x12\x10\n\x08minproto\x18\x04 \x02(\x05\x12\x10\n\x08maxproto\x18\x05 \x02(\x05\x12\x0c\n\x04mode\x18\x06 \x02(\x05\x12\x0b\n\x03uid\x18\x07 \x01(\x05\x12\x0b\n\x03gid\x18\x08 \x01(\x05\x12\x0f\n\x07read_fd\x18\t \x01(\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'autofs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AUTOFS_ENTRY']._serialized_start=17
  _globals['_AUTOFS_ENTRY']._serialized_end=167
# @@protoc_insertion_point(module_scope)
