# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tun.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'tun.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ttun.proto\x1a\nopts.proto\"L\n\rtunfile_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0e\n\x06netdev\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65tached\x18\x03 \x01(\x08\x12\r\n\x05ns_id\x18\x04 \x01(\r\"e\n\x0etun_link_entry\x12\x14\n\x05\x66lags\x18\x01 \x02(\rB\x05\xd2?\x02\x08\x01\x12\r\n\x05owner\x18\x02 \x02(\x05\x12\r\n\x05group\x18\x03 \x02(\x05\x12\x0f\n\x07vnethdr\x18\x04 \x02(\r\x12\x0e\n\x06sndbuf\x18\x05 \x02(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tun_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TUN_LINK_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_TUN_LINK_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_TUNFILE_ENTRY']._serialized_start=25
  _globals['_TUNFILE_ENTRY']._serialized_end=101
  _globals['_TUN_LINK_ENTRY']._serialized_start=103
  _globals['_TUN_LINK_ENTRY']._serialized_end=204
# @@protoc_insertion_point(module_scope)
