# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: mm.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'mm.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import vma_pb2 as vma__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x08mm.proto\x1a\nopts.proto\x1a\tvma.proto\">\n\x0e\x61io_ring_entry\x12\n\n\x02id\x18\x01 \x02(\x04\x12\x0e\n\x06nr_req\x18\x02 \x02(\r\x12\x10\n\x08ring_len\x18\x03 \x02(\r\"\xce\x03\n\x08mm_entry\x12\x1c\n\rmm_start_code\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1a\n\x0bmm_end_code\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1c\n\rmm_start_data\x18\x03 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1a\n\x0bmm_end_data\x18\x04 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1d\n\x0emm_start_stack\x18\x05 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cmm_start_brk\x18\x06 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x15\n\x06mm_brk\x18\x07 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cmm_arg_start\x18\x08 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x19\n\nmm_arg_end\x18\t \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cmm_env_start\x18\n \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x19\n\nmm_env_end\x18\x0b \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x13\n\x0b\x65xe_file_id\x18\x0c \x02(\r\x12\x15\n\rmm_saved_auxv\x18\r \x03(\x04\x12\x18\n\x04vmas\x18\x0e \x03(\x0b\x32\n.vma_entry\x12\x10\n\x08\x64umpable\x18\x0f \x01(\x05\x12\x1d\n\x04\x61ios\x18\x10 \x03(\x0b\x32\x0f.aio_ring_entry\x12\x14\n\x0cthp_disabled\x18\x11 \x01(\x08')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_start_code']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_start_code']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_end_code']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_end_code']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_start_data']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_start_data']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_end_data']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_end_data']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_start_stack']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_start_stack']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_start_brk']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_start_brk']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_brk']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_brk']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_arg_start']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_arg_start']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_arg_end']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_arg_end']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_env_start']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_env_start']._serialized_options = b'\322?\002\010\001'
  _globals['_MM_ENTRY'].fields_by_name['mm_env_end']._loaded_options = None
  _globals['_MM_ENTRY'].fields_by_name['mm_env_end']._serialized_options = b'\322?\002\010\001'
  _globals['_AIO_RING_ENTRY']._serialized_start=35
  _globals['_AIO_RING_ENTRY']._serialized_end=97
  _globals['_MM_ENTRY']._serialized_start=100
  _globals['_MM_ENTRY']._serialized_end=562
# @@protoc_insertion_point(module_scope)
