# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fdinfo.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'fdinfo.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import regfile_pb2 as regfile__pb2
import sk_inet_pb2 as sk__inet__pb2
import ns_pb2 as ns__pb2
import packet_sock_pb2 as packet__sock__pb2
import sk_netlink_pb2 as sk__netlink__pb2
import eventfd_pb2 as eventfd__pb2
import eventpoll_pb2 as eventpoll__pb2
import signalfd_pb2 as signalfd__pb2
import tun_pb2 as tun__pb2
import timerfd_pb2 as timerfd__pb2
import fsnotify_pb2 as fsnotify__pb2
import ext_file_pb2 as ext__file__pb2
import sk_unix_pb2 as sk__unix__pb2
import fifo_pb2 as fifo__pb2
import pipe_pb2 as pipe__pb2
import pidfd_pb2 as pidfd__pb2
import tty_pb2 as tty__pb2
import memfd_pb2 as memfd__pb2
import bpfmap_file_pb2 as bpfmap__file__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x66\x64info.proto\x1a\rregfile.proto\x1a\rsk-inet.proto\x1a\x08ns.proto\x1a\x11packet-sock.proto\x1a\x10sk-netlink.proto\x1a\reventfd.proto\x1a\x0f\x65ventpoll.proto\x1a\x0esignalfd.proto\x1a\ttun.proto\x1a\rtimerfd.proto\x1a\x0e\x66snotify.proto\x1a\x0e\x65xt-file.proto\x1a\rsk-unix.proto\x1a\nfifo.proto\x1a\npipe.proto\x1a\x0bpidfd.proto\x1a\ttty.proto\x1a\x0bmemfd.proto\x1a\x11\x62pfmap-file.proto\"n\n\x0c\x66\x64info_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05\x66lags\x18\x02 \x02(\r\x12\x17\n\x04type\x18\x03 \x02(\x0e\x32\t.fd_types\x12\n\n\x02\x66\x64\x18\x04 \x02(\r\x12\x1e\n\x16xattr_security_selinux\x18\x05 \x01(\t\"\xa0\x05\n\nfile_entry\x12\x17\n\x04type\x18\x01 \x02(\x0e\x32\t.fd_types\x12\n\n\x02id\x18\x02 \x02(\r\x12\x1c\n\x03reg\x18\x03 \x01(\x0b\x32\x0f.reg_file_entry\x12\x1b\n\x03isk\x18\x04 \x01(\x0b\x32\x0e.inet_sk_entry\x12\x1b\n\x03nsf\x18\x05 \x01(\x0b\x32\x0e.ns_file_entry\x12\x1f\n\x03psk\x18\x06 \x01(\x0b\x32\x12.packet_sock_entry\x12\x1f\n\x04nlsk\x18\x07 \x01(\x0b\x32\x11.netlink_sk_entry\x12 \n\x03\x65\x66\x64\x18\x08 \x01(\x0b\x32\x13.eventfd_file_entry\x12#\n\x04\x65pfd\x18\t \x01(\x0b\x32\x15.eventpoll_file_entry\x12\x1d\n\x04sgfd\x18\n \x01(\x0b\x32\x0f.signalfd_entry\x12\x1c\n\x04tunf\x18\x0b \x01(\x0b\x32\x0e.tunfile_entry\x12\x1b\n\x03tfd\x18\x0c \x01(\x0b\x32\x0e.timerfd_entry\x12 \n\x03ify\x18\r \x01(\x0b\x32\x13.inotify_file_entry\x12!\n\x03\x66\x66y\x18\x0e \x01(\x0b\x32\x14.fanotify_file_entry\x12\x1c\n\x03\x65xt\x18\x0f \x01(\x0b\x32\x0f.ext_file_entry\x12\x1b\n\x03usk\x18\x10 \x01(\x0b\x32\x0e.unix_sk_entry\x12\x19\n\x04\x66ifo\x18\x11 \x01(\x0b\x32\x0b.fifo_entry\x12\x19\n\x04pipe\x18\x12 \x01(\x0b\x32\x0b.pipe_entry\x12\x1c\n\x03tty\x18\x13 \x01(\x0b\x32\x0f.tty_file_entry\x12 \n\x05memfd\x18\x14 \x01(\x0b\x32\x11.memfd_file_entry\x12\x1f\n\x03\x62pf\x18\x15 \x01(\x0b\x32\x12.bpfmap_file_entry\x12\x1b\n\x05pidfd\x18\x16 \x01(\x0b\x32\x0c.pidfd_entry*\x9f\x02\n\x08\x66\x64_types\x12\x07\n\x03UND\x10\x00\x12\x07\n\x03REG\x10\x01\x12\x08\n\x04PIPE\x10\x02\x12\x08\n\x04\x46IFO\x10\x03\x12\n\n\x06INETSK\x10\x04\x12\n\n\x06UNIXSK\x10\x05\x12\x0b\n\x07\x45VENTFD\x10\x06\x12\r\n\tEVENTPOLL\x10\x07\x12\x0b\n\x07INOTIFY\x10\x08\x12\x0c\n\x08SIGNALFD\x10\t\x12\x0c\n\x08PACKETSK\x10\n\x12\x07\n\x03TTY\x10\x0b\x12\x0c\n\x08\x46\x41NOTIFY\x10\x0c\x12\r\n\tNETLINKSK\x10\r\x12\x06\n\x02NS\x10\x0e\x12\x08\n\x04TUNF\x10\x0f\x12\x07\n\x03\x45XT\x10\x10\x12\x0b\n\x07TIMERFD\x10\x11\x12\t\n\x05MEMFD\x10\x12\x12\n\n\x06\x42PFMAP\x10\x13\x12\t\n\x05PIDFD\x10\x14\x12\r\n\x07\x43TL_TTY\x10\xfe\xff\x03\x12\x11\n\x0b\x41UTOFS_PIPE\x10\xff\xff\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fdinfo_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FD_TYPES']._serialized_start=1082
  _globals['_FD_TYPES']._serialized_end=1369
  _globals['_FDINFO_ENTRY']._serialized_start=294
  _globals['_FDINFO_ENTRY']._serialized_end=404
  _globals['_FILE_ENTRY']._serialized_start=407
  _globals['_FILE_ENTRY']._serialized_end=1079
# @@protoc_insertion_point(module_scope)
