# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-aarch64.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'core-aarch64.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x63ore-aarch64.proto\x1a\nopts.proto\"O\n\x17user_aarch64_regs_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\x12\n\n\x02sp\x18\x02 \x02(\x04\x12\n\n\x02pc\x18\x03 \x02(\x04\x12\x0e\n\x06pstate\x18\x04 \x02(\x04\"N\n!user_aarch64_fpsimd_context_entry\x12\r\n\x05vregs\x18\x01 \x03(\x04\x12\x0c\n\x04\x66psr\x18\x02 \x02(\r\x12\x0c\n\x04\x66pcr\x18\x03 \x02(\r\"\xcb\x01\n\x10pac_address_keys\x12\x12\n\napiakey_lo\x18\x01 \x02(\x04\x12\x12\n\napiakey_hi\x18\x02 \x02(\x04\x12\x12\n\napibkey_lo\x18\x03 \x02(\x04\x12\x12\n\napibkey_hi\x18\x04 \x02(\x04\x12\x12\n\napdakey_lo\x18\x05 \x02(\x04\x12\x12\n\napdakey_hi\x18\x06 \x02(\x04\x12\x12\n\napdbkey_lo\x18\x07 \x02(\x04\x12\x12\n\napdbkey_hi\x18\x08 \x02(\x04\x12\x17\n\x0fpac_enabled_key\x18\t \x02(\x04\":\n\x10pac_generic_keys\x12\x12\n\napgakey_lo\x18\x01 \x02(\x04\x12\x12\n\napgakey_hi\x18\x02 \x02(\x04\"d\n\x08pac_keys\x12+\n\x10pac_address_keys\x18\x06 \x01(\x0b\x32\x11.pac_address_keys\x12+\n\x10pac_generic_keys\x18\x07 \x01(\x0b\x32\x11.pac_generic_keys\"\xc3\x01\n\x13thread_info_aarch64\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0b\n\x03tls\x18\x02 \x02(\x04\x12/\n\x06gpregs\x18\x03 \x02(\x0b\x32\x18.user_aarch64_regs_entryB\x05\xd2?\x02\x08\x01\x12\x32\n\x06\x66psimd\x18\x04 \x02(\x0b\x32\".user_aarch64_fpsimd_context_entry\x12\x1b\n\x08pac_keys\x18\x05 \x01(\x0b\x32\t.pac_keys')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_aarch64_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_AARCH64'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_AARCH64'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_AARCH64'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_AARCH64'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_AARCH64_REGS_ENTRY']._serialized_start=34
  _globals['_USER_AARCH64_REGS_ENTRY']._serialized_end=113
  _globals['_USER_AARCH64_FPSIMD_CONTEXT_ENTRY']._serialized_start=115
  _globals['_USER_AARCH64_FPSIMD_CONTEXT_ENTRY']._serialized_end=193
  _globals['_PAC_ADDRESS_KEYS']._serialized_start=196
  _globals['_PAC_ADDRESS_KEYS']._serialized_end=399
  _globals['_PAC_GENERIC_KEYS']._serialized_start=401
  _globals['_PAC_GENERIC_KEYS']._serialized_end=459
  _globals['_PAC_KEYS']._serialized_start=461
  _globals['_PAC_KEYS']._serialized_end=561
  _globals['_THREAD_INFO_AARCH64']._serialized_start=564
  _globals['_THREAD_INFO_AARCH64']._serialized_end=759
# @@protoc_insertion_point(module_scope)
