# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-riscv64.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'core-riscv64.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x63ore-riscv64.proto\x1a\nopts.proto\"\x9b\x03\n\x17user_riscv64_regs_entry\x12\n\n\x02pc\x18\x01 \x02(\x04\x12\n\n\x02ra\x18\x02 \x02(\x04\x12\n\n\x02sp\x18\x03 \x02(\x04\x12\n\n\x02gp\x18\x04 \x02(\x04\x12\n\n\x02tp\x18\x05 \x02(\x04\x12\n\n\x02t0\x18\x06 \x02(\x04\x12\n\n\x02t1\x18\x07 \x02(\x04\x12\n\n\x02t2\x18\x08 \x02(\x04\x12\n\n\x02s0\x18\t \x02(\x04\x12\n\n\x02s1\x18\n \x02(\x04\x12\n\n\x02\x61\x30\x18\x0b \x02(\x04\x12\n\n\x02\x61\x31\x18\x0c \x02(\x04\x12\n\n\x02\x61\x32\x18\r \x02(\x04\x12\n\n\x02\x61\x33\x18\x0e \x02(\x04\x12\n\n\x02\x61\x34\x18\x0f \x02(\x04\x12\n\n\x02\x61\x35\x18\x10 \x02(\x04\x12\n\n\x02\x61\x36\x18\x11 \x02(\x04\x12\n\n\x02\x61\x37\x18\x12 \x02(\x04\x12\n\n\x02s2\x18\x13 \x02(\x04\x12\n\n\x02s3\x18\x14 \x02(\x04\x12\n\n\x02s4\x18\x15 \x02(\x04\x12\n\n\x02s5\x18\x16 \x02(\x04\x12\n\n\x02s6\x18\x17 \x02(\x04\x12\n\n\x02s7\x18\x18 \x02(\x04\x12\n\n\x02s8\x18\x19 \x02(\x04\x12\n\n\x02s9\x18\x1a \x02(\x04\x12\x0b\n\x03s10\x18\x1b \x02(\x04\x12\x0b\n\x03s11\x18\x1c \x02(\x04\x12\n\n\x02t3\x18\x1d \x02(\x04\x12\n\n\x02t4\x18\x1e \x02(\x04\x12\n\n\x02t5\x18\x1f \x02(\x04\x12\n\n\x02t6\x18  \x02(\x04\"3\n\x18user_riscv64_d_ext_entry\x12\t\n\x01\x66\x18\x01 \x03(\x04\x12\x0c\n\x04\x66\x63sr\x18\x02 \x02(\r\"\x9d\x01\n\x13thread_info_riscv64\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0b\n\x03tls\x18\x02 \x02(\x04\x12/\n\x06gpregs\x18\x03 \x02(\x0b\x32\x18.user_riscv64_regs_entryB\x05\xd2?\x02\x08\x01\x12)\n\x06\x66psimd\x18\x04 \x02(\x0b\x32\x19.user_riscv64_d_ext_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_riscv64_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_RISCV64'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_RISCV64'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_RISCV64'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_RISCV64'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_RISCV64_REGS_ENTRY']._serialized_start=35
  _globals['_USER_RISCV64_REGS_ENTRY']._serialized_end=446
  _globals['_USER_RISCV64_D_EXT_ENTRY']._serialized_start=448
  _globals['_USER_RISCV64_D_EXT_ENTRY']._serialized_end=499
  _globals['_THREAD_INFO_RISCV64']._serialized_start=502
  _globals['_THREAD_INFO_RISCV64']._serialized_end=659
# @@protoc_insertion_point(module_scope)
