# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: mnt.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'mnt.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tmnt.proto\x1a\nopts.proto\"\xe7\x02\n\tmnt_entry\x12\x0e\n\x06\x66stype\x18\x01 \x02(\r\x12\x0e\n\x06mnt_id\x18\x02 \x02(\r\x12\x17\n\x08root_dev\x18\x03 \x02(\rB\x05\xd2?\x02 \x01\x12\x15\n\rparent_mnt_id\x18\x04 \x02(\r\x12\x14\n\x05\x66lags\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0c\n\x04root\x18\x06 \x02(\t\x12\x12\n\nmountpoint\x18\x07 \x02(\t\x12\x0e\n\x06source\x18\x08 \x02(\t\x12\x0f\n\x07options\x18\t \x02(\t\x12\x11\n\tshared_id\x18\n \x01(\r\x12\x11\n\tmaster_id\x18\x0b \x01(\r\x12\x13\n\x0bwith_plugin\x18\x0c \x01(\x08\x12\x11\n\text_mount\x18\r \x01(\x08\x12\x0e\n\x06\x66sname\x18\x0e \x01(\t\x12\x18\n\x10internal_sharing\x18\x0f \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x10 \x01(\x08\x12\x17\n\x08sb_flags\x18\x11 \x01(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07\x65xt_key\x18\x12 \x01(\t*\x90\x02\n\x06\x66stype\x12\x0f\n\x0bUNSUPPORTED\x10\x00\x12\x08\n\x04PROC\x10\x01\x12\t\n\x05SYSFS\x10\x02\x12\x0c\n\x08\x44\x45VTMPFS\x10\x03\x12\x0f\n\x0b\x42INFMT_MISC\x10\x04\x12\t\n\x05TMPFS\x10\x05\x12\n\n\x06\x44\x45VPTS\x10\x06\x12\t\n\x05SIMFS\x10\x07\x12\n\n\x06PSTORE\x10\x08\x12\x0e\n\nSECURITYFS\x10\t\x12\x0b\n\x07\x46USECTL\x10\n\x12\x0b\n\x07\x44\x45\x42UGFS\x10\x0b\x12\n\n\x06\x43GROUP\x10\x0c\x12\x08\n\x04\x41UFS\x10\r\x12\n\n\x06MQUEUE\x10\x0e\x12\x08\n\x04\x46USE\x10\x0f\x12\x08\n\x04\x41UTO\x10\x10\x12\r\n\tOVERLAYFS\x10\x11\x12\n\n\x06\x41UTOFS\x10\x12\x12\x0b\n\x07TRACEFS\x10\x13\x12\x0b\n\x07\x43GROUP2\x10\x17')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mnt_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MNT_ENTRY'].fields_by_name['root_dev']._loaded_options = None
  _globals['_MNT_ENTRY'].fields_by_name['root_dev']._serialized_options = b'\322?\002 \001'
  _globals['_MNT_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_MNT_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_MNT_ENTRY'].fields_by_name['sb_flags']._loaded_options = None
  _globals['_MNT_ENTRY'].fields_by_name['sb_flags']._serialized_options = b'\322?\002\010\001'
  _globals['_FSTYPE']._serialized_start=388
  _globals['_FSTYPE']._serialized_end=660
  _globals['_MNT_ENTRY']._serialized_start=26
  _globals['_MNT_ENTRY']._serialized_end=385
# @@protoc_insertion_point(module_scope)
