# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-ppc64.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'core-ppc64.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63ore-ppc64.proto\x1a\nopts.proto\"\xc2\x01\n\x15user_ppc64_regs_entry\x12\x0b\n\x03gpr\x18\x01 \x03(\x04\x12\x0b\n\x03nip\x18\x02 \x02(\x04\x12\x0b\n\x03msr\x18\x03 \x02(\x04\x12\x11\n\torig_gpr3\x18\x04 \x02(\x04\x12\x0b\n\x03\x63tr\x18\x05 \x02(\x04\x12\x0c\n\x04link\x18\x06 \x02(\x04\x12\x0b\n\x03xer\x18\x07 \x02(\x04\x12\x0b\n\x03\x63\x63r\x18\x08 \x02(\x04\x12\x0c\n\x04trap\x18\t \x02(\x04\x12\x0e\n\x06texasr\x18\n \x01(\x04\x12\r\n\x05tfhar\x18\x0b \x01(\x04\x12\r\n\x05tfiar\x18\x0c \x01(\x04\"*\n\x18user_ppc64_fpstate_entry\x12\x0e\n\x06\x66pregs\x18\x01 \x03(\x04\":\n\x18user_ppc64_vrstate_entry\x12\x0e\n\x06vrregs\x18\x01 \x03(\x04\x12\x0e\n\x06vrsave\x18\x02 \x02(\r\",\n\x19user_ppc64_vsxstate_entry\x12\x0f\n\x07vsxregs\x18\x01 \x03(\x04\"\xc8\x01\n\x18user_ppc64_tm_regs_entry\x12&\n\x06gpregs\x18\x01 \x02(\x0b\x32\x16.user_ppc64_regs_entry\x12*\n\x07\x66pstate\x18\x02 \x01(\x0b\x32\x19.user_ppc64_fpstate_entry\x12*\n\x07vrstate\x18\x03 \x01(\x0b\x32\x19.user_ppc64_vrstate_entry\x12,\n\x08vsxstate\x18\x04 \x01(\x0b\x32\x1a.user_ppc64_vsxstate_entry\"\x93\x02\n\x11thread_info_ppc64\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12-\n\x06gpregs\x18\x02 \x02(\x0b\x32\x16.user_ppc64_regs_entryB\x05\xd2?\x02\x08\x01\x12*\n\x07\x66pstate\x18\x03 \x01(\x0b\x32\x19.user_ppc64_fpstate_entry\x12*\n\x07vrstate\x18\x04 \x01(\x0b\x32\x19.user_ppc64_vrstate_entry\x12,\n\x08vsxstate\x18\x05 \x01(\x0b\x32\x1a.user_ppc64_vsxstate_entry\x12*\n\x07tmstate\x18\x06 \x01(\x0b\x32\x19.user_ppc64_tm_regs_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_ppc64_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_PPC64'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_PPC64'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_PPC64'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_PPC64'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_PPC64_REGS_ENTRY']._serialized_start=33
  _globals['_USER_PPC64_REGS_ENTRY']._serialized_end=227
  _globals['_USER_PPC64_FPSTATE_ENTRY']._serialized_start=229
  _globals['_USER_PPC64_FPSTATE_ENTRY']._serialized_end=271
  _globals['_USER_PPC64_VRSTATE_ENTRY']._serialized_start=273
  _globals['_USER_PPC64_VRSTATE_ENTRY']._serialized_end=331
  _globals['_USER_PPC64_VSXSTATE_ENTRY']._serialized_start=333
  _globals['_USER_PPC64_VSXSTATE_ENTRY']._serialized_end=377
  _globals['_USER_PPC64_TM_REGS_ENTRY']._serialized_start=380
  _globals['_USER_PPC64_TM_REGS_ENTRY']._serialized_end=580
  _globals['_THREAD_INFO_PPC64']._serialized_start=583
  _globals['_THREAD_INFO_PPC64']._serialized_end=858
# @@protoc_insertion_point(module_scope)
