# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: timer.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'timer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0btimer.proto\"H\n\x0citimer_entry\x12\x0c\n\x04isec\x18\x01 \x02(\x04\x12\r\n\x05iusec\x18\x02 \x02(\x04\x12\x0c\n\x04vsec\x18\x03 \x02(\x04\x12\r\n\x05vusec\x18\x04 \x02(\x04\"\xd7\x01\n\x11posix_timer_entry\x12\r\n\x05it_id\x18\x01 \x02(\r\x12\x10\n\x08\x63lock_id\x18\x02 \x02(\r\x12\x10\n\x08si_signo\x18\x03 \x02(\r\x12\x17\n\x0fit_sigev_notify\x18\x04 \x02(\r\x12\x11\n\tsival_ptr\x18\x05 \x02(\x04\x12\x0f\n\x07overrun\x18\x06 \x02(\r\x12\x0c\n\x04isec\x18\x07 \x02(\x04\x12\r\n\x05insec\x18\x08 \x02(\x04\x12\x0c\n\x04vsec\x18\t \x02(\x04\x12\r\n\x05vnsec\x18\n \x02(\x04\x12\x18\n\x10notify_thread_id\x18\x0b \x01(\x05\"\x8d\x01\n\x11task_timers_entry\x12\x1b\n\x04real\x18\x01 \x02(\x0b\x32\r.itimer_entry\x12\x1b\n\x04virt\x18\x02 \x02(\x0b\x32\r.itimer_entry\x12\x1b\n\x04prof\x18\x03 \x02(\x0b\x32\r.itimer_entry\x12!\n\x05posix\x18\x04 \x03(\x0b\x32\x12.posix_timer_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'timer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ITIMER_ENTRY']._serialized_start=15
  _globals['_ITIMER_ENTRY']._serialized_end=87
  _globals['_POSIX_TIMER_ENTRY']._serialized_start=90
  _globals['_POSIX_TIMER_ENTRY']._serialized_end=305
  _globals['_TASK_TIMERS_ENTRY']._serialized_start=308
  _globals['_TASK_TIMERS_ENTRY']._serialized_end=449
# @@protoc_insertion_point(module_scope)
