# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-arm.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'core-arm.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63ore-arm.proto\x1a\nopts.proto\"\xf5\x01\n\x13user_arm_regs_entry\x12\n\n\x02r0\x18\x01 \x02(\r\x12\n\n\x02r1\x18\x02 \x02(\r\x12\n\n\x02r2\x18\x03 \x02(\r\x12\n\n\x02r3\x18\x04 \x02(\r\x12\n\n\x02r4\x18\x05 \x02(\r\x12\n\n\x02r5\x18\x06 \x02(\r\x12\n\n\x02r6\x18\x07 \x02(\r\x12\n\n\x02r7\x18\x08 \x02(\r\x12\n\n\x02r8\x18\t \x02(\r\x12\n\n\x02r9\x18\n \x02(\r\x12\x0b\n\x03r10\x18\x0b \x02(\r\x12\n\n\x02\x66p\x18\x0c \x02(\r\x12\n\n\x02ip\x18\r \x02(\r\x12\n\n\x02sp\x18\x0e \x02(\r\x12\n\n\x02lr\x18\x0f \x02(\r\x12\n\n\x02pc\x18\x10 \x02(\r\x12\x0c\n\x04\x63psr\x18\x11 \x02(\r\x12\x0f\n\x07orig_r0\x18\x12 \x02(\r\"j\n\x17user_arm_vfpstate_entry\x12\x10\n\x08vfp_regs\x18\x01 \x03(\x04\x12\r\n\x05\x66pscr\x18\x02 \x02(\r\x12\r\n\x05\x66pexc\x18\x03 \x02(\r\x12\x0e\n\x06\x66pinst\x18\x04 \x02(\r\x12\x0f\n\x07\x66pinst2\x18\x05 \x02(\r\"\x95\x01\n\x0fthread_info_arm\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0b\n\x03tls\x18\x02 \x02(\r\x12+\n\x06gpregs\x18\x03 \x02(\x0b\x32\x14.user_arm_regs_entryB\x05\xd2?\x02\x08\x01\x12)\n\x07\x66pstate\x18\x04 \x02(\x0b\x32\x18.user_arm_vfpstate_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_arm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_ARM'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_ARM'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_ARM'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_ARM'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_ARM_REGS_ENTRY']._serialized_start=31
  _globals['_USER_ARM_REGS_ENTRY']._serialized_end=276
  _globals['_USER_ARM_VFPSTATE_ENTRY']._serialized_start=278
  _globals['_USER_ARM_VFPSTATE_ENTRY']._serialized_end=384
  _globals['_THREAD_INFO_ARM']._serialized_start=387
  _globals['_THREAD_INFO_ARM']._serialized_end=536
# @@protoc_insertion_point(module_scope)
