# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fh.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'fh.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x08\x66h.proto\x1a\nopts.proto\"U\n\x08\x66h_entry\x12\r\n\x05\x62ytes\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\r\x12\x0e\n\x06handle\x18\x03 \x03(\x04\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x0e\n\x06mnt_id\x18\x05 \x01(\r\"F\n\x11irmap_cache_entry\x12\x14\n\x03\x64\x65v\x18\x01 \x02(\rB\x07\xd2?\x04 \x01(\x01\x12\r\n\x05inode\x18\x02 \x02(\x04\x12\x0c\n\x04path\x18\x03 \x02(\t*!\n\x0e\x66h_entry_sizes\x12\x0f\n\x0bmin_entries\x10\x10')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fh_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IRMAP_CACHE_ENTRY'].fields_by_name['dev']._loaded_options = None
  _globals['_IRMAP_CACHE_ENTRY'].fields_by_name['dev']._serialized_options = b'\322?\004 \001(\001'
  _globals['_FH_ENTRY_SIZES']._serialized_start=183
  _globals['_FH_ENTRY_SIZES']._serialized_end=216
  _globals['_FH_ENTRY']._serialized_start=24
  _globals['_FH_ENTRY']._serialized_end=109
  _globals['_IRMAP_CACHE_ENTRY']._serialized_start=111
  _globals['_IRMAP_CACHE_ENTRY']._serialized_end=181
# @@protoc_insertion_point(module_scope)
