# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: inventory.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'inventory.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import core_pb2 as core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0finventory.proto\x1a\ncore.proto\" \n\rplugins_entry\x12\x0f\n\x07plugins\x18\x0c \x03(\t\"\xdc\x02\n\x0finventory_entry\x12\x13\n\x0bimg_version\x18\x01 \x02(\r\x12\x15\n\rfdinfo_per_id\x18\x02 \x01(\x08\x12&\n\x08root_ids\x18\x03 \x01(\x0b\x32\x14.task_kobj_ids_entry\x12\x11\n\tns_per_id\x18\x04 \x01(\x08\x12\x13\n\x0broot_cg_set\x18\x05 \x01(\r\x12\x19\n\x07lsmtype\x18\x06 \x01(\x0e\x32\x08.lsmtype\x12\x13\n\x0b\x64ump_uptime\x18\x08 \x01(\x04\x12\x15\n\rpre_dump_mode\x18\t \x01(\r\x12\x11\n\ttcp_close\x18\n \x01(\x08\x12\x1b\n\x13network_lock_method\x18\x0b \x01(\r\x12%\n\rplugins_entry\x18\x0c \x01(\x0b\x32\x0e.plugins_entry\x12\x18\n\x10\x64ump_criu_run_id\x18\r \x01(\t\x12\x15\n\rallow_uprobes\x18\x0e \x01(\x08*0\n\x07lsmtype\x12\n\n\x06NO_LSM\x10\x00\x12\x0b\n\x07SELINUX\x10\x01\x12\x0c\n\x08\x41PPARMOR\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'inventory_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LSMTYPE']._serialized_start=416
  _globals['_LSMTYPE']._serialized_end=464
  _globals['_PLUGINS_ENTRY']._serialized_start=31
  _globals['_PLUGINS_ENTRY']._serialized_end=63
  _globals['_INVENTORY_ENTRY']._serialized_start=66
  _globals['_INVENTORY_ENTRY']._serialized_end=414
# @@protoc_insertion_point(module_scope)
