# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: packet-sock.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'packet-sock.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11packet-sock.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\":\n\rpacket_mclist\x12\r\n\x05index\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\r\x12\x0c\n\x04\x61\x64\x64r\x18\x03 \x02(\x0c\"\x94\x01\n\x0bpacket_ring\x12\x12\n\nblock_size\x18\x01 \x02(\r\x12\x10\n\x08\x62lock_nr\x18\x02 \x02(\r\x12\x12\n\nframe_size\x18\x03 \x02(\r\x12\x10\n\x08\x66rame_nr\x18\x04 \x02(\r\x12\x12\n\nretire_tmo\x18\x05 \x02(\r\x12\x13\n\x0bsizeof_priv\x18\x06 \x02(\r\x12\x10\n\x08\x66\x65\x61tures\x18\x07 \x02(\r\"\xb6\x03\n\x11packet_sock_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\r\x12\x10\n\x08protocol\x18\x03 \x02(\r\x12\x14\n\x05\x66lags\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07ifindex\x18\x05 \x02(\r\x12\x19\n\x04\x66own\x18\x06 \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\x07 \x02(\x0b\x32\x0e.sk_opts_entry\x12\x0f\n\x07version\x18\x08 \x02(\r\x12\x0f\n\x07reserve\x18\t \x02(\r\x12\x10\n\x08\x61ux_data\x18\n \x02(\x08\x12\x10\n\x08orig_dev\x18\x0b \x02(\x08\x12\x10\n\x08vnet_hdr\x18\x0c \x02(\x08\x12\x0c\n\x04loss\x18\r \x02(\x08\x12\x11\n\ttimestamp\x18\x0e \x02(\r\x12\x13\n\x0b\x63opy_thresh\x18\x0f \x02(\r\x12\x1e\n\x06mclist\x18\x10 \x03(\x0b\x32\x0e.packet_mclist\x12\x1a\n\x06\x66\x61nout\x18\x11 \x01(\r:\n4294967295\x12\x1d\n\x07rx_ring\x18\x12 \x01(\x0b\x32\x0c.packet_ring\x12\x1d\n\x07tx_ring\x18\x13 \x01(\x0b\x32\x0c.packet_ring\x12\r\n\x05ns_id\x18\x14 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'packet_sock_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PACKET_SOCK_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_PACKET_SOCK_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_PACKET_MCLIST']._serialized_start=60
  _globals['_PACKET_MCLIST']._serialized_end=118
  _globals['_PACKET_RING']._serialized_start=121
  _globals['_PACKET_RING']._serialized_end=269
  _globals['_PACKET_SOCK_ENTRY']._serialized_start=272
  _globals['_PACKET_SOCK_ENTRY']._serialized_end=710
# @@protoc_insertion_point(module_scope)
