# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sk-netlink.proto
# Protobuf Python Version: 6.33.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    1,
    '',
    'sk-netlink.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10sk-netlink.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\"\xf1\x01\n\x10netlink_sk_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03ino\x18\x02 \x02(\r\x12\x10\n\x08protocol\x18\x03 \x02(\r\x12\r\n\x05state\x18\x04 \x02(\r\x12\x14\n\x05\x66lags\x18\x06 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0e\n\x06portid\x18\x07 \x02(\r\x12\x0e\n\x06groups\x18\x08 \x03(\r\x12\x12\n\ndst_portid\x18\t \x02(\r\x12\x11\n\tdst_group\x18\n \x02(\r\x12\x19\n\x04\x66own\x18\x0b \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\x0c \x02(\x0b\x32\x0e.sk_opts_entry\x12\r\n\x05ns_id\x18\r \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sk_netlink_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NETLINK_SK_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_NETLINK_SK_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_NETLINK_SK_ENTRY']._serialized_start=60
  _globals['_NETLINK_SK_ENTRY']._serialized_end=301
# @@protoc_insertion_point(module_scope)
